@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 402 $ : Last Committed Revision
- * $Date: 2009-08-23 13:44:39 -0700 (Sun, 23 Aug 2009) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -130,7 +130,7 @@ ams_ManageAgentList(ams_p ams)
   MUTEX_LOCK(alist->lock);
   for(index=0; index<alist->size; index++)
   {
-    if((current_agent = ListSearch(alist->list, index)))
+    if((current_agent = (MCAgent_t)ListSearch(alist->list, index)))
     {
 			if(current_agent->binary) {continue;} /* Do not deal with binary agents */
       MUTEX_UNLOCK(alist->lock);
@@ -180,7 +180,7 @@ ams_ManageAgentList(ams_p ams)
           } else {
             /* Rename the agent: This is done so that if the agent is coming back here
              * very quickly, the names will not conflict. */
-            current_agent->name = realloc(
+            current_agent->name = (char*)realloc(
                 current_agent->name,
                 sizeof(char) * (strlen(current_agent->name) + 10)
                 );
