@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 468 $ : Last Committed Revision
- * $Date: 2010-05-17 12:52:54 -0700 (Mon, 17 May 2010) $ : Last Committed Date */
+ * $Revision: 530 $ : Last Committed Revision
+ * $Date: 2010-06-16 16:52:19 -0700 (Wed, 16 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -150,7 +150,6 @@ typedef name##_t* name##_p;
       (void*) arg \
       ) < 0) { \
 			printf("pthread_create failed. Trying again...\n"); \
-			usleep(100000); \
 	}
 
 #define THREAD_CANCEL( thread_handle ) \
@@ -479,7 +478,7 @@ WaitForSingleObject( *(queue->touched_signal), INFINITE )
   }
 
 #define WARN( message ) \
-  fprintf(stderr, "WARNING: "); \
+  fprintf(stderr, "\nWARNING: "); \
   fprintf(stderr, message ); \
   fprintf(stderr, " %s:%d\n", __FILE__, __LINE__ )
 
