@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 457 $ : Last Committed Revision
- * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
+ * $Revision: 531 $ : Last Committed Revision
+ * $Date: 2010-06-17 10:39:34 -0700 (Thu, 17 Jun 2010) $ : Last Committed Date */
 /*
  * "$Id: mxml-entity.c,v 1.1 2007/05/23 20:43:27 david_ko Exp $"
  *
@@ -35,7 +35,11 @@
  * Include necessary headers...
  */
 
+#ifdef _WIN32
+#include "winconfig.h"
+#else
 #include "config.h"
+#endif
 #include "mxml.h"
 
 
